@@ -20,13 +20,8 @@
 
 #include <iostream>
 
-
 #include <QFile>
-
 #include <QDebug>
-
-
-
 #include <QApplication>
 #include <KAboutData>
 #include <KCrash>
@@ -54,10 +49,10 @@ int main(int argc, char* argv[])
 {
 	KLocalizedString::setApplicationDomain("kturtle");
 
-	// TODO: for >=KF5.15 use KCrash::initialize();
-	KCrash::setCrashHandler(KCrash::defaultCrashHandler);
-
 	QApplication app(argc, argv);
+	app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+
+	KCrash::initialize();
 
 	/* for migration*/
 	QStringList configFiles;
@@ -111,7 +106,7 @@ int main(int argc, char* argv[])
 
 		///////////////// run in DBUS mode /////////////////
 		Translator::instance()->setLanguage();
-		new Interpreter(0, true);
+		new Interpreter(nullptr, true);
 		
 		return app.exec();
 
@@ -121,7 +116,7 @@ int main(int argc, char* argv[])
 		QFile inputFile(parser.value("parse"));
 		if (!inputFile.open(QIODevice::ReadOnly | QIODevice::Text)) {
 			std::cout << "Could not open file: " << qPrintable(parser.value("parse")) << std::endl;
-			std::cout << "Exitting..." << std::endl;
+			std::cout << "Exiting..." << std::endl;
 			return 1;
 		}
 		
@@ -207,7 +202,7 @@ int main(int argc, char* argv[])
 		  // free some memory
 
 		// init the interpreter
-		Interpreter* interpreter = new Interpreter(0, true);  // set testing to true
+		Interpreter* interpreter = new Interpreter(nullptr, true);  // set testing to true
 		interpreter->initialize(localizedScript);
 
 		// install the echoer
